
<a id='changelog-0.6.9.dev1'></a>
# 0.6.9 — 2023-01-15

## Changed

- Something new

- The munged value is always added to the function, but only conditionally applied if it is not None. This is to lead the way toward creating proper function headers with setup code.

- A new function is defined and called.

<a id='changelog-0.6.2.dev12'></a>
# 0.6.2.dev12 — 2023-01-14

